@@ -399,6 +399,27 @@ class ApiConnection(Session):
         response.raise_for_status()
         return response.json()["content"]["data"]
 
+    def delete_search(
+        self,
+        search_id: str = None,
+    ):
+        """
+        https://docs.complyadvantage.com/api-docs/#delete-searches-id
+
+        :param search_id: Either the numeric search ID, or the search REF
+        :return:
+        """
+
+        response = self.delete(
+            f"{self.url}/searches/{search_id}"
+        )
+        response.raise_for_status()
+
+        if response.status_code == 204:
+            return True
+
+        return False
+
     def update_search_entities(
         self,
         search_id: str = None,
